@@ -1,4 +1,5 @@
-from collections.abc import Sized, Iterator
+# -*- coding: utf-8 -*-
+from collections.abc import Iterator, Sized
 
 
 class ResponsePaginator(Sized, Iterator):
@@ -30,7 +31,7 @@ class ResponsePaginator(Sized, Iterator):
         Keyword arguments to send to :meth:`apistar.Client.request` with each request.
         """
 
-        self.current_page = self.request_kwargs.get('page', 0)
+        self.current_page = self.request_kwargs.get("page", 0)
         """The current page number. 0 or ``page`` from :meth:`apistar.Client.request` keyword arguments
         if no pages have been requested."""
 
@@ -38,9 +39,9 @@ class ResponsePaginator(Sized, Iterator):
         """Has any request been sent"""
 
     def _fetch_page(self, page):
-        self.request_kwargs['page'] = page
+        self.request_kwargs["page"] = page
         self.data = self.client.request(*self.request_args, **self.request_kwargs)
-        self.results = self.data.get('results', [])
+        self.results = self.data.get("results", [])
         self.current_page = page
         self._started = True
 
@@ -49,7 +50,7 @@ class ResponsePaginator(Sized, Iterator):
 
     def __next__(self):
         if len(self.results) < 1:
-            if self.data and self.data.get('next') is None:
+            if self.data and self.data.get("next") is None:
                 raise StopIteration
             self._fetch_page(self.current_page + 1)
 
@@ -65,10 +66,10 @@ class ResponsePaginator(Sized, Iterator):
             self._fetch_page(1)
         elif not self._started:
             self._fetch_page(self.current_page)
-        return self.data['count']
+        return self.data["count"]
 
     def __repr__(self):
-        return '<{} via {!r}: {!r} {!r}>'.format(
+        return "<{} via {!r}: {!r} {!r}>".format(
             self.__class__.__name__,
             self.client,
             self.request_args,
